@@ -36,11 +36,11 @@ def devices():
     p = SdkToolsPopen(['adb', "devices"])
     if p.returncode != 0:
         raise FDroidException("An error occured when finding devices: %s" % p.output)
-    lines = [l for l in p.output.splitlines() if not l.startswith('* ')]
+    lines = [line for line in p.output.splitlines() if not line.startswith('* ')]
     if len(lines) < 3:
         return []
     lines = lines[1:-1]
-    return [l.split()[0] for l in lines]
+    return [line.split()[0] for line in lines]
 
 
 def main():
@@ -50,7 +50,7 @@ def main():
     # Parse command line...
     parser = ArgumentParser(usage="%(prog)s [options] [APPID[:VERCODE] [APPID[:VERCODE] ...]]")
     common.setup_global_opts(parser)
-    parser.add_argument("appid", nargs='*', help=_("applicationId with optional versionCode in the form APPID[:VERCODE]"))
+    parser.add_argument("appid", nargs='*', help=_("application ID with optional versionCode in the form APPID[:VERCODE]"))
     parser.add_argument("-a", "--all", action="store_true", default=False,
                         help=_("Install all signed applications available"))
     options = parser.parse_args()
@@ -70,7 +70,7 @@ def main():
         vercodes = common.read_pkg_args(options.appid, True)
         apks = {appid: None for appid in vercodes}
 
-        # Get the signed apk with the highest vercode
+        # Get the signed APK with the highest vercode
         for apkfile in sorted(glob.glob(os.path.join(output_dir, '*.apk'))):
 
             try:
@@ -85,7 +85,7 @@ def main():
 
         for appid, apk in apks.items():
             if not apk:
-                raise FDroidException(_("No signed apk available for %s") % appid)
+                raise FDroidException(_("No signed APK available for %s") % appid)
 
     else:
 
@@ -109,8 +109,8 @@ def main():
                 continue
 
             if fail == "INSTALL_FAILED_ALREADY_EXISTS":
-                logging.warn(_("'{apkfilename}' is already installed on {dev}.")
-                             .format(apkfilename=apk, dev=dev))
+                logging.warning(_('"{apkfilename}" is already installed on {dev}.')
+                                .format(apkfilename=apk, dev=dev))
             else:
                 raise FDroidException(_("Failed to install '{apkfilename}' on {dev}: {error}")
                                       .format(apkfilename=apk, dev=dev, error=fail))
